@@ -11,7 +11,7 @@ from enum import Enum
 List  = typing.List
 Tuple = typing.Tuple
 pypi_base_url = "http://zifuture.com:1556/fs/pypi"
-version = "1.1.19"
+version = "1.1.21"
 
 lean_metas = [
     {
@@ -432,13 +432,20 @@ def create_symlink_directory(directory, print_info=False):
     for file in files:
         if file.startswith("lib") and file.find(".so") != -1 and not file.endswith(".so"):
             source = os.path.join(directory, file)
-            link_name = os.path.join(directory, file[:file.find(".so")] + ".so")
-            if os.path.exists(link_name):
-                os.remove(link_name)
+            link_name = file[:file.find(".so")] + ".so"
+            if link_name.find("-") != -1:
+                p = link_name.find("-")
+                e = link_name.find(".", p)
+                if e != -1:
+                    link_name = link_name[:p] + link_name[e:]
+            link_path = os.path.join(directory, link_name)
+
+            if os.path.exists(link_path):
+                os.remove(link_path)
 
             if print_info:
-                print(f"Create symlink {link_name}")
-            os.symlink(source, link_name)
+                print(f"Create symlink {link_path}")
+            os.symlink(source, link_path)
 
 def set_exec_permission(directory):
     for file in os.listdir(directory):
