@@ -77,10 +77,10 @@ def do_get_cpp_pkg(args):
         shutil.rmtree(package_root)
 
     print(f"Extract package {name} to {package_root}")
-    downloader.extract_zip_to(file, trtpy.cpp_packages_root)
+    downloader.extract_zip_to(file, trtpy.cpp_packages_root, False)
     if os.path.isdir(package_lib_root):
         print(f"Create symlink {package_lib_root}")
-        trtpy.create_symlink_directory(package_lib_root, False)
+        trtpy.create_symlink_directory(package_lib_root, True)
     print("Done")
     return 0
 
@@ -422,6 +422,56 @@ def do_templ_search(args):
         print(f"-{i+1}. {name} [{language}] : {descript}")
     return 0
 
+def do_series_detial(args):
+    
+    if args.name == "" or args.name == ".":
+        print_current = True
+        current_dir = os.path.abspath(".")
+        config_json_file = os.path.join(current_dir, ".series", "config.json")
+        if not os.path.isfile(config_json_file):
+            print(f"Current is not series folder")
+            return 1
+    else:
+        print_current = False
+        meta_url = f"{trtpy.pypi_base_url}/code_template/{args.name}.series.json"
+        meta_cache_local_file = os.path.join(downloader.CACHE_ROOT, "code_template", f"{args.name}.series.json")
+        if not args.download and os.path.exists(meta_cache_local_file):
+            print(f"Use cache {meta_cache_local_file}")
+        elif not downloader.download_to_file(meta_url, meta_cache_local_file):
+            print(f"Series '{args.name}' not found")
+            return 1
+        config_json_file = meta_cache_local_file
+
+    meta = json.load(open(config_json_file, "r"))
+    current_index = meta["current-index"]
+    templ_list = meta["list-templ"]
+        
+    index_names_map = []
+    for index, (templ_name, templ_descript) in enumerate(templ_list):
+        p = templ_name.find("-")
+        if p != -1:
+            names = [templ_name[:p], templ_name[p+1:]]
+        else:
+            names = [templ_name]    
+        
+        names = [name for name in names if name.strip() != ""]
+        index_names_map.append([index, names, templ_descript])
+
+    print(f"List templ: ")
+    for index, names, templ_descript in index_names_map:
+        if len(names) > 0:
+            if len(names) == 1:
+                print(names[0])
+            else:
+                chapter = names[0]
+                caption = names[1]
+                print(f"chapter: {chapter}, caption: {caption}, description: {templ_descript}")
+
+    if print_current:
+        current_item = templ_list[current_index]
+        print(f"Current is {current_item[0]}, {current_item[1]}")
+    return 1
+
 def do_series_list(args):
 
     url = f"{trtpy.pypi_base_url}/code_template/list.series.txt"
@@ -647,6 +697,10 @@ if __name__ == "__main__":
     p.add_argument("--raw", action="store_true", help="do not replace variables")
     p.add_argument("--download", action="store_true", help="ignore cache and download template")
 
+    p = subp.add_parser("series-detial", help="change series proj")
+    p.add_argument("name", type=str, default="", help="series name", nargs="?")
+    p.add_argument("--download", action="store_true", help="ignore cache and download template")
+
     p = new_parser_with_version("prep-vars", help="replace local file variables")
     p.add_argument("file_or_directory", type=str, help=f"Project directory or file, file filter = {process_code_template.include_list}")
 
@@ -692,7 +746,8 @@ if __name__ == "__main__":
         "get-series":    do_get_series,
         "list-series":   do_series_list,
         "search-series": do_series_search,
-        "change-proj":   do_change_proj
+        "change-proj":   do_change_proj,
+        "series-detial": do_series_detial
     }
 
     if args.cmd in cmd_funcs:
